@@ -1,13 +1,18 @@
 import click
 
 from ..compatibility import COILED_VERSION
-from .cluster import cluster
+from .batch import batch_group
+from .cluster import better_logs, cluster
+from .config import config
 from .curl import curl
 from .diagnostics import diagnostics
 from .env import env
+from .hello import hello
 from .login import login
-from .notebook import notebook
+from .notebook import notebook_group
 from .package_sync import package_sync
+from .prefect import prefect
+from .run import run
 from .setup import setup
 
 CONTEXT_SETTINGS = {"help_option_names": ["-h", "--help"]}
@@ -25,6 +30,13 @@ cli.add_command(env)
 cli.add_command(diagnostics)
 cli.add_command(setup)
 cli.add_command(cluster)
-cli.add_command(notebook)
+cli.add_command(notebook_group)
 cli.add_command(package_sync)
+cli.add_command(prefect)
 cli.add_command(curl)
+cli.add_command(config)
+cli.add_command(run)
+cli.add_command(batch_group)
+cli.add_command(better_logs, "logs")
+cli.add_command(hello)
+cli.add_command(hello, "quickstart")
